@@ -226,6 +226,7 @@ pointLik.alm <- function(object, ...){
                             "dnorm" = dnorm(y, mean=mu, sd=scale, log=TRUE),
                             "dfnorm" = dfnorm(y, mu=mu, sigma=scale, log=TRUE),
                             "dlnorm" = dlnorm(y, meanlog=mu, sdlog=scale, log=TRUE),
+                            "dbcnorm" = dbcnorm(y, mu=mu, sigma=scale, lambda=object$other$lambda, log=TRUE),
                             "dlaplace" = dlaplace(y, mu=mu, scale=scale, log=TRUE),
                             "dalaplace" = dalaplace(y, mu=mu, scale=scale, alpha=object$other$alpha, log=TRUE),
                             "dlogis" = dlogis(y, location=mu, scale=scale, log=TRUE),
@@ -241,11 +242,12 @@ pointLik.alm <- function(object, ...){
                                         pnorm(mu[!ot], mean=0, sd=1, lower.tail=FALSE, log.p=TRUE))
     );
 
-    # If this is a mixture model, take the respective probabilities into account
+    # If this is a mixture model, take the respective probabilities into account (differential entropy)
     if(is.alm(object$occurrence)){
         likValues[!otU] <- -switch(distribution,
                                    "dnorm" =,
                                    "dfnorm" =,
+                                   "dbcnorm" =,
                                    "dlnorm" = log(sqrt(2*pi)*scale)+0.5,
                                    "dlaplace" =,
                                    "dalaplace" = (1 + log(2*scale)),
@@ -668,6 +670,24 @@ predict.alm <- function(object, newdata=NULL, interval=c("none", "confidence", "
         greyboxForecast$mean <- exp(greyboxForecast$mean);
         greyboxForecast$scale <- sdlog;
     }
+    else if(object$distribution=="dbcnorm"){
+        sigma <- sqrt(greyboxForecast$variance);
+        # If negative values were produced, zero them out
+        if(any(greyboxForecast$mean<0)){
+            greyboxForecast$mean[greyboxForecast$mean<0] <- 0;
+        }
+        if(interval!="n"){
+            greyboxForecast$lower[] <- qbcnorm(levelLow,greyboxForecast$mean,sigma,object$other$lambda);
+            greyboxForecast$upper[] <- qbcnorm(levelUp,greyboxForecast$mean,sigma,object$other$lambda);
+        }
+        if(object$other$lambda==0){
+            greyboxForecast$mean[] <- exp(greyboxForecast$mean)
+        }
+        else{
+            greyboxForecast$mean[] <- (greyboxForecast$mean*object$other$lambda+1)^{1/object$other$lambda};
+        }
+        greyboxForecast$scale <- sigma;
+    }
     else if(object$distribution=="dlogis"){
         # Use the connection between the variance and scale in logistic distribution
         scale <- sqrt(greyboxForecast$variances * 3 / pi^2);
@@ -1114,6 +1134,12 @@ predict.almari <- function(object, newdata=NULL, interval=c("none", "confidence"
                 colnames(matrixOfxregFull)[nonariParametersNumber+c(1:ariOrder)] <- paste0(ariNames,"Log");
             }
         }
+        else if(object$distribution=="dbcnorm"){
+            # Use Box-Cox if there are zeroes
+            matrixOfxregFull[,nonariParametersNumber+c(1:ariOrder)] <- (matrixOfxregFull[,nonariParametersNumber+c(1:ariOrder)]^
+                                                                            object$other$lambda-1)/object$other$lambda;
+            colnames(matrixOfxregFull)[nonariParametersNumber+c(1:ariOrder)] <- paste0(ariNames,"Box-Cox");
+        }
         else if(object$distribution=="dchisq"){
             matrixOfxregFull[,nonariParametersNumber+c(1:ariOrder)] <- sqrt(matrixOfxregFull[,nonariParametersNumber+c(1:ariOrder)]);
             colnames(matrixOfxregFull)[nonariParametersNumber+c(1:ariOrder)] <- paste0(ariNames,"Sqrt");
@@ -1450,10 +1476,10 @@ plot.predict.greybox <- function(x, ...){
             yHoldout <- x$newdata[,yName];
             if(!any(is.na(yHoldout))){
                 if(x$newdataProvided){
-                    yActuals <- ts(c(yActuals,yHoldout), start=yStart, frequency=yFrequency);
+                    yActuals <- ts(c(yActuals,unlist(yHoldout)), start=yStart, frequency=yFrequency);
                 }
                 else{
-                    yActuals <- ts(yHoldout, start=yForecastStart, frequency=yFrequency);
+                    yActuals <- ts(unlist(yHoldout), start=yForecastStart, frequency=yFrequency);
                 }
                 # If this is occurrence model, then transform actual to the occurrence
                 if(any(x$distribution==c("pnorm","plogis"))){
@@ -1639,6 +1665,7 @@ print.summary.alm <- function(x, ...){
                       "ds" = "S",
                       "dfnorm" = "Folded Normal",
                       "dlnorm" = "Log Normal",
+                      "dbcnorm" = paste0("Box-Cox Normal with lambda=",round(x$other$lambda,2)),
                       "dchisq" = paste0("Chi-Squared with df=",round(x$other$df,2)),
                       "dpois" = "Poisson",
                       "dnbinom" = paste0("Negative Binomial with size=",round(x$other$size,2)),
@@ -1689,6 +1716,7 @@ print.summary.greybox <- function(x, ...){
                       "ds" = "S",
                       "dfnorm" = "Folded Normal",
                       "dlnorm" = "Log Normal",
+                      "dbcnorm" = "Box-Cox Normal",
                       "dchisq" = "Chi-Squared",
                       "dpois" = "Poisson",
                       "dnbinom" = "Negative Binomial",
@@ -1734,6 +1762,7 @@ print.summary.greyboxC <- function(x, ...){
                       "ds" = "S",
                       "dfnorm" = "Folded Normal",
                       "dlnorm" = "Log Normal",
+                      "dbcnorm" = "Box-Cox Normal",
                       "dchisq" = "Chi-Squared",
                       "dpois" = "Poisson",
                       "dnbinom" = "Negative Binomial",
@@ -1965,7 +1994,7 @@ vcov.alm <- function(object, ...){
 
     interceptIsNeeded <- any(names(coef(object))=="(Intercept)");
 
-    if(iOrderNone & any(object$distribution==c("dlnorm","plogis","pnorm"))){
+    if(iOrderNone & any(object$distribution==c("dlnorm","dbcnorm","plogis","pnorm"))){
         # This is based on the underlying normal distribution of logit / probit model
         matrixXreg <- object$data[object$subset,-1,drop=FALSE];
         if(interceptIsNeeded){
@@ -2051,6 +2080,9 @@ vcov.alm <- function(object, ...){
         else if(object$distribution=="dfnorm"){
             newCall$sigma <- object$other$sigma;
         }
+        else if(object$distribution=="dbcnorm"){
+            newCall$lambda <- object$other$lambda;
+        }
         newCall$vcovProduce <- TRUE;
         # newCall$occurrence <- NULL;
         newCall$occurrence <- object$occurrence;
